==> tellico_2.3.9+dfsg.1.orig.tar.xz: tellico-2.3.9+dfsg.1/src/core/netaccess.h <==
/***************************************************************************
    Copyright (C) 2006-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_NETACCESS_H
#define TELLICO_NETACCESS_H

#include <QObject>
#include <QPixmap>

class KUrl;
class KFileItem;

namespace Tellico {

class NetAccess : public QObject {
Q_OBJECT

public:
  static bool download(const KUrl& u, QString& target, QWidget* window, bool quiet=false);
  static QPixmap filePreview(const KUrl& fileName, int size=196);
  static QPixmap filePreview(const KFileItem& item, int size=196);
  static void removeTempFile(const QString& name);

  static QString lastErrorString();

private slots:
  void slotPreview(const KFileItem& item, const QPixmap& pix);

private:
  QPixmap m_preview;
  static QString s_lastErrorMessage;
};

}
#endif

==> tellico_4.1.5.orig.tar.xz: tellico-4.1.5/src/core/netaccess.h <==
/***************************************************************************
    Copyright (C) 2006-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_NETACCESS_H
#define TELLICO_NETACCESS_H

#include <QObject>
#include <QPixmap>

class QUrl;

class KFileItem;

namespace Tellico {

class NetAccess : public QObject {
Q_OBJECT

public:
  static bool download(const QUrl& u, QString& target, QWidget* window, bool quiet=false);
  static QPixmap filePreview(const QUrl& fileName, int size=196);
  static QPixmap filePreview(const KFileItem& item, int size=196);
  static void removeTempFile(const QString& name);
  static bool exists(const QUrl& url, bool sourceSide, QWidget* window);

  static QString lastErrorString();

private Q_SLOTS:
  void slotPreview(const KFileItem& item, const QPixmap& pix);

private:
  QPixmap m_preview;
  static QString s_lastErrorMessage;
};

}
#endif
